# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nomad`](#nomad): Installs, configures, and manages nomad
* [`nomad::server_recovery`](#nomad--server_recovery): This class is used to generate a peers.json and a recovery script file for Nomad servers. It is used to recover from a Nomad server outage.

#### Private Classes

* `nomad::config`: This class is called from nomad::init to install the config file.
* `nomad::install`: This class is called from nomad::init to install the config file.
* `nomad::reload_service`: This class is meant to be called from certain configuration changes that support reload.
* `nomad::run_service`: This class is meant to be called from nomad It ensure the service is running

## Classes

### <a name="nomad"></a>`nomad`

Installs, configures, and manages nomad

#### Examples

##### To set up a single nomad server, with several agents attached, on the server.

```puppet
class { 'nomad':
  config_hash => {
    'region'     => 'us-west',
    'datacenter' => 'ptk',
    'log_level'  => 'INFO',
    'bind_addr'  => '0.0.0.0',
    'data_dir'   => '/opt/nomad',
    'server'     => {
      'enabled'          => true,
      'bootstrap_expect' => 3,
    }
  }
}
```

##### On the agent(s)

```puppet
class { 'nomad':
  config_hash => {
    'region'     => 'us-west',
    'datacenter' => 'ptk',
    'log_level'  => 'INFO',
    'bind_addr'  => '0.0.0.0',
    'data_dir'   => '/opt/nomad',
    'client'     => {
      'enabled' => true,
      'servers' => [
        "nomad01.your-org.pvt:4647",
        "nomad02.your-org.pvt:4647",
        "nomad03.your-org.pvt:4647"
      ]
    }
  },
}
```

##### Install from zip file for a CPU architecture HashiCorp does not provide native packages for.

```puppet
class { 'nomad':
  arch                => 'armv7l',
  install_method      => 'url',
  manage_service_file => true,
  version             => '1.0.3', # check latest version at https://github.com/hashicorp/nomad/blob/master/CHANGELOG.md
  config_hash         => {
    'region'     => 'us-west',
    'datacenter' => 'ptk',
    'log_level'  => 'INFO',
    'bind_addr'  => '0.0.0.0',
    'data_dir'   => '/opt/nomad',
    'client'     => {
      'enabled' => true,
      'servers' => [
        "nomad01.your-org.pvt:4647",
        "nomad02.your-org.pvt:4647",
        "nomad03.your-org.pvt:4647"
      ]
    }
  },
}
```

##### Disable install and service components

```puppet
class { 'nomad':
  install_method => 'none',
  manage_service => false,
  config_hash    => {
    region     => 'us-west',
    datacenter => 'ptk',
    log_level  => 'INFO',
    bind_addr  => '0.0.0.0',
    data_dir   => '/opt/nomad',
    'client'     => {
      'enabled' => true,
      'servers' => [
        "nomad01.your-org.pvt:4647",
        "nomad02.your-org.pvt:4647",
        "nomad03.your-org.pvt:4647"
      ]
    }
  },
}
```

#### Parameters

The following parameters are available in the `nomad` class:

* [`arch`](#-nomad--arch)
* [`purge_config_dir`](#-nomad--purge_config_dir)
* [`data_dir_mode`](#-nomad--data_dir_mode)
* [`plugin_dir_mode`](#-nomad--plugin_dir_mode)
* [`join_wan`](#-nomad--join_wan)
* [`bin_dir`](#-nomad--bin_dir)
* [`version`](#-nomad--version)
* [`install_method`](#-nomad--install_method)
* [`os`](#-nomad--os)
* [`download_url`](#-nomad--download_url)
* [`download_url_base`](#-nomad--download_url_base)
* [`download_extension`](#-nomad--download_extension)
* [`package_name`](#-nomad--package_name)
* [`config_dir`](#-nomad--config_dir)
* [`extra_options`](#-nomad--extra_options)
* [`config_hash`](#-nomad--config_hash)
* [`config_defaults`](#-nomad--config_defaults)
* [`config_validator`](#-nomad--config_validator)
* [`config_mode`](#-nomad--config_mode)
* [`manage_repo`](#-nomad--manage_repo)
* [`manage_service`](#-nomad--manage_service)
* [`manage_service_file`](#-nomad--manage_service_file)
* [`pretty_config`](#-nomad--pretty_config)
* [`service_enable`](#-nomad--service_enable)
* [`service_ensure`](#-nomad--service_ensure)
* [`restart_on_change`](#-nomad--restart_on_change)
* [`env_vars`](#-nomad--env_vars)
* [`user`](#-nomad--user)
* [`group`](#-nomad--group)
* [`server_recovery`](#-nomad--server_recovery)
* [`recovery_nomad_server_regex`](#-nomad--recovery_nomad_server_regex)
* [`recovery_nomad_server_hash`](#-nomad--recovery_nomad_server_hash)
* [`recovery_network_interface`](#-nomad--recovery_network_interface)
* [`recovery_rpc_port`](#-nomad--recovery_rpc_port)

##### <a name="-nomad--arch"></a>`arch`

Data type: `String[1]`

cpu architecture

##### <a name="-nomad--purge_config_dir"></a>`purge_config_dir`

Data type: `Boolean`

Purge config files no longer generated by Puppet

Default value: `true`

##### <a name="-nomad--data_dir_mode"></a>`data_dir_mode`

Data type: `Stdlib::Filemode`

Specify unix permissions for data dir directory managed by this module

Default value: `'0755'`

##### <a name="-nomad--plugin_dir_mode"></a>`plugin_dir_mode`

Data type: `Stdlib::Filemode`

Specify unix permissions for plugin dir directory managed by this module

Default value: `'0755'`

##### <a name="-nomad--join_wan"></a>`join_wan`

Data type: `Optional[String[1]]`

join nomad cluster over the WAN

Default value: `undef`

##### <a name="-nomad--bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

location of the nomad binary

Default value: `'/usr/bin'`

##### <a name="-nomad--version"></a>`version`

Data type: `String[1]`

Specify version of nomad binary to download.

Default value: `'installed'`

##### <a name="-nomad--install_method"></a>`install_method`

Data type: `Enum['none', 'package', 'url']`

install via system package, download and extract from a url.

Default value: `'package'`

##### <a name="-nomad--os"></a>`os`

Data type: `String[1]`

operation system to install for

Default value: `downcase($facts['kernel'])`

##### <a name="-nomad--download_url"></a>`download_url`

Data type: `Optional[String[1]]`

download url to download from

Default value: `undef`

##### <a name="-nomad--download_url_base"></a>`download_url_base`

Data type: `String[1]`

download hostname to down from

Default value: `'https://releases.hashicorp.com/nomad/'`

##### <a name="-nomad--download_extension"></a>`download_extension`

Data type: `String[1]`

archive type to download

Default value: `'zip'`

##### <a name="-nomad--package_name"></a>`package_name`

Data type: `String[1]`

Only valid when the install_method == package.

Default value: `'nomad'`

##### <a name="-nomad--config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

location of the nomad configuration

Default value: `'/etc/nomad.d'`

##### <a name="-nomad--extra_options"></a>`extra_options`

Data type: `Optional[String[1]]`

Extra arguments to be passed to the nomad agent

Default value: `undef`

##### <a name="-nomad--config_hash"></a>`config_hash`

Data type: `Hash`

Use this to populate the JSON config file for nomad.

Default value: `{}`

##### <a name="-nomad--config_defaults"></a>`config_defaults`

Data type: `Hash`

default set of config settings

Default value: `{}`

##### <a name="-nomad--config_validator"></a>`config_validator`

Data type:

```puppet
Variant[
    Enum['nomad_validator', 'ruby_validator'], Pattern[/\A.*\ %\z/]
  ]
```

Use this to set the JSON config file validation command. It defaults to nomad validator which is currenly missing some validation checks.
If ruby is available on the system you could use 'ruby_validator', or create your own script (ending with space and % symbol).

Default value: `'nomad_validator'`

##### <a name="-nomad--config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`

Use this to set the JSON config file mode for nomad.

Default value: `'0660'`

##### <a name="-nomad--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Configure the upstream HashiCorp repository. Only relevant when $nomad::install_method = 'package'.

Default value: `true`

##### <a name="-nomad--manage_service"></a>`manage_service`

Data type: `Boolean`

manage the nomad service

Default value: `true`

##### <a name="-nomad--manage_service_file"></a>`manage_service_file`

Data type: `Boolean`

create and manage the systemd service file

Default value: `false`

##### <a name="-nomad--pretty_config"></a>`pretty_config`

Data type: `Boolean`

Generates a human readable JSON config file.

Default value: `false`

##### <a name="-nomad--service_enable"></a>`service_enable`

Data type: `Boolean`

enable the nomad service

Default value: `true`

##### <a name="-nomad--service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

ensure the state of the nomad service

Default value: `'running'`

##### <a name="-nomad--restart_on_change"></a>`restart_on_change`

Data type: `Boolean`

Determines whether to restart nomad agent on $config_hash changes. This will not affect reloads when service, check or watch configs change.

Default value: `true`

##### <a name="-nomad--env_vars"></a>`env_vars`

Data type: `Hash[String[1], String]`

Hash of optional environment variables that should be passed to nomad

Default value: `{}`

##### <a name="-nomad--user"></a>`user`

Data type: `String[1]`

User to run the Nomad binary as. Also used as owner of directories and config files managed by this module.

Default value: `'root'`

##### <a name="-nomad--group"></a>`group`

Data type: `String[1]`

Group to run the Nomad binary as. Also used as group of directories and config files managed by this module.

Default value: `'root'`

##### <a name="-nomad--server_recovery"></a>`server_recovery`

Data type: `Boolean`

Nomad server outage recovery configuration

Default value: `false`

##### <a name="-nomad--recovery_nomad_server_regex"></a>`recovery_nomad_server_regex`

Data type: `Optional[String]`

Regex to match Nomad server hostnames within the same puppet environment. It requires PuppetDB and it's mutually exclusive with nomad_server_hash.

Default value: `undef`

##### <a name="-nomad--recovery_nomad_server_hash"></a>`recovery_nomad_server_hash`

Data type: `Optional[Hash]`

If you don't have the PuppetDB you can supply a Hash with server IPs and corresponding node-ids. It works without PuppetDB and it's mutually exclusive with nomad_server_regex.

Default value: `undef`

##### <a name="-nomad--recovery_network_interface"></a>`recovery_network_interface`

Data type: `Optional[String]`

NIC where Nomad server IP is configured

Default value: `undef`

##### <a name="-nomad--recovery_rpc_port"></a>`recovery_rpc_port`

Data type: `Stdlib::Port`

Nomad server RPC port

Default value: `4647`

### <a name="nomad--server_recovery"></a>`nomad::server_recovery`

This class is used to generate a peers.json and a recovery script file for Nomad servers.
It is used to recover from a Nomad server outage.

#### Examples

##### using PuppetDB

```puppet
class { 'nomad':
  config_hash                 => {
    'region'     => 'us-west',
    'datacenter' => 'ptk',
    'bind_addr'  => '0.0.0.0',
    'data_dir'   => '/opt/nomad',
    'server'     => {
      'enabled'          => true,
      'bootstrap_expect' => 3,
    },
  },
  server_recovery             => true,
  recovery_nomad_server_regex => 'nomad-server0',
  recovery_network_interface  => 'eth0',
}
```

#### Parameters

The following parameters are available in the `nomad::server_recovery` class:

* [`nomad_server_regex`](#-nomad--server_recovery--nomad_server_regex)
* [`nomad_server_hash`](#-nomad--server_recovery--nomad_server_hash)
* [`network_interface`](#-nomad--server_recovery--network_interface)
* [`rpc_port`](#-nomad--server_recovery--rpc_port)

##### <a name="-nomad--server_recovery--nomad_server_regex"></a>`nomad_server_regex`

Data type: `Optional[String]`

Regex to match Nomad server hostnames within the same puppet environment. It's mutually exclusive with nomad_server_hash.

Default value: `undef`

##### <a name="-nomad--server_recovery--nomad_server_hash"></a>`nomad_server_hash`

Data type: `Optional[Hash]`

If you don't have the PuppetDB you can supply a Hash with server IPs and corresponding node-ids. It's mutually exclusive with nomad_server_regex.

Default value: `undef`

##### <a name="-nomad--server_recovery--network_interface"></a>`network_interface`

Data type: `Optional[String]`

NIC where Nomad server IP is configured

Default value: `undef`

##### <a name="-nomad--server_recovery--rpc_port"></a>`rpc_port`

Data type: `Stdlib::Port`

Nomad server RPC port

Default value: `4647`

